import i18n from "../../locale/i18n";
import { SideBarItem } from "./SidebarItem";
import { TenantUserRole } from "@/application/enums/core/tenants/TenantUserRole";
import { UserType } from "@/application/enums/core/users/UserType";
import { SvgIcon } from "../enums/shared/SvgIcon";

export const AppSidebar: SideBarItem[] = [
  {
    title: i18n.global.t("app.sidebar.app"),
    path: "",
    items: [
      {
        title: i18n.global.t("app.sidebar.dashboard"),
        path: "/app/dashboard",
        icon: SvgIcon.DASHBOARD,
        userRoles: [TenantUserRole.OWNER, TenantUserRole.ADMIN, TenantUserRole.MEMBER, TenantUserRole.GUEST],
      },
      {
        title: i18n.global.t("todo.tasks"),
        path: "/app/tasks",
        icon: SvgIcon.TASKS,
        userRoles: [TenantUserRole.OWNER, TenantUserRole.ADMIN, TenantUserRole.MEMBER, TenantUserRole.GUEST],
      },
      {
        title: i18n.global.t("app.navbar.settings"),
        icon: SvgIcon.SETTINGS,
        userRoles: [TenantUserRole.OWNER, TenantUserRole.ADMIN],
        path: "/app/settings",
        items: [
          {
            title: i18n.global.t("app.navbar.profile"),
            path: "/app/settings/profile",
          },
          {
            title: i18n.global.t("models.workspace.plural"),
            path: "/app/settings/workspaces",
            userRoles: [TenantUserRole.OWNER, TenantUserRole.ADMIN],
          },
          {
            title: i18n.global.t("settings.members.title"),
            path: "/app/settings/members",
            userRoles: [TenantUserRole.OWNER, TenantUserRole.ADMIN],
          },
          {
            title: i18n.global.t("settings.subscription.title"),
            path: "/app/settings/subscription",
            userRoles: [TenantUserRole.OWNER],
          },
          {
            title: i18n.global.t("app.navbar.tenant"),
            path: "/app/settings/tenant",
            userRoles: [TenantUserRole.OWNER],
          },
        ],
      },
    ],
  },
  {
    title: i18n.global.t("admin.title"),
    path: "",
    items: [
      {
        title: i18n.global.t("admin.switchToAdmin"),
        path: "/admin/tenants",
        icon: SvgIcon.ADMIN,
        userTypes: [UserType.Admin],
      },
    ],
  },
];
